"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AuthIdRefreshToken = exports.schemaAuthIdRefreshTokenClaim = void 0;
const joi_1 = __importDefault(require("joi"));
const cm_libs_context_aware_error_1 = require("cm-libs-context-aware-error");
const auth_base_token_1 = require("./auth-base-token");
const _uuid = joi_1.default.string().length(21);
exports.schemaAuthIdRefreshTokenClaim = {
    ...auth_base_token_1.schemaBaseToken,
    userUuid: _uuid.required()
};
class AuthIdRefreshToken extends auth_base_token_1.AuthBaseToken {
    constructor(secret, expiresIn, schema, algorithm) {
        super(secret, expiresIn, schema, algorithm);
    }
    static init(secret, expiresIn, algorithm) {
        this.self = new AuthIdRefreshToken(secret, expiresIn, joi_1.default.object(exports.schemaAuthIdRefreshTokenClaim), algorithm);
        return this;
    }
    static term() {
        this.self = undefined;
    }
    static get instance() {
        return this.self || (0, cm_libs_context_aware_error_1.throwError)(cm_libs_context_aware_error_1.errors.NOT_INITIALIZED, 'AuthIdRefreshToken initialization is required');
    }
    sign(claim, expiresIn, notBefore) {
        if (auth_base_token_1.TokenKind.REFRESH_TOKEN !== claim.kind) {
            (0, cm_libs_context_aware_error_1.throwError)(cm_libs_context_aware_error_1.errors.MISMATCHED, 'Token kind is invalid', { claim });
        }
        return super.sign(claim, expiresIn, notBefore);
    }
    verify(token) {
        const claim = super.verify(token);
        /* istanbul ignore next */
        if (auth_base_token_1.TokenKind.REFRESH_TOKEN !== claim.kind) {
            (0, cm_libs_context_aware_error_1.throwError)(cm_libs_context_aware_error_1.errors.MISMATCHED, 'Token kind is invalid', { token: claim });
        }
        return claim;
    }
    static get isEnabled() {
        return undefined !== this.self;
    }
}
exports.AuthIdRefreshToken = AuthIdRefreshToken;
//# sourceMappingURL=auth-id-refresh-token.js.map