import Joi from 'joi';
import { AnyAbility } from '@casl/ability';
import { Algorithm, AuthBaseToken, BaseTokenClaim, AppDomain } from './auth-base-token';
export declare type IdToken = {
    appDomain: AppDomain;
    productEntityUuid?: string;
    userId: number | bigint;
    userUuid: string;
    localeCode: string;
    ability: AnyAbility;
};
export declare type AuthIdTokenClaim = BaseTokenClaim & {
    userUuid: string;
    localeCode: string;
};
export declare const schemaAuthIdTokenClaim: {
    userUuid: Joi.StringSchema;
    localeCode: Joi.StringSchema;
    iat: Joi.NumberSchema;
    exp: Joi.NumberSchema;
    kind: Joi.StringSchema;
    uuid: Joi.StringSchema;
    appDomain: Joi.StringSchema;
    productEntityUuid: Joi.StringSchema;
};
export declare class AuthIdToken extends AuthBaseToken<AuthIdTokenClaim> {
    private static self;
    private constructor();
    static init(secret: string, expiresIn: string | number, algorithm?: Algorithm): typeof AuthIdToken;
    static term(): void;
    static get instance(): AuthIdToken;
    sign(claim: AuthIdTokenClaim, expiresIn?: string | number, notBefore?: string | number): string;
    verify(token: string): AuthIdTokenClaim;
    static get isEnabled(): boolean;
}
